@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,10 +14,11 @@
 # limitations under the License.
 #
 
+from google.cloud.asset_v1.services.asset_service.client import AssetServiceClient
 from google.cloud.asset_v1.services.asset_service.async_client import (
     AssetServiceAsyncClient,
 )
-from google.cloud.asset_v1.services.asset_service.client import AssetServiceClient
+
 from google.cloud.asset_v1.types.asset_service import AnalyzeIamPolicyLongrunningRequest
 from google.cloud.asset_v1.types.asset_service import (
     AnalyzeIamPolicyLongrunningResponse,
@@ -28,7 +28,6 @@ from google.cloud.asset_v1.types.asset_service import AnalyzeIamPolicyResponse
 from google.cloud.asset_v1.types.asset_service import BatchGetAssetsHistoryRequest
 from google.cloud.asset_v1.types.asset_service import BatchGetAssetsHistoryResponse
 from google.cloud.asset_v1.types.asset_service import BigQueryDestination
-from google.cloud.asset_v1.types.asset_service import ContentType
 from google.cloud.asset_v1.types.asset_service import CreateFeedRequest
 from google.cloud.asset_v1.types.asset_service import DeleteFeedRequest
 from google.cloud.asset_v1.types.asset_service import ExportAssetsRequest
@@ -40,6 +39,8 @@ from google.cloud.asset_v1.types.asset_service import GcsOutputResult
 from google.cloud.asset_v1.types.asset_service import GetFeedRequest
 from google.cloud.asset_v1.types.asset_service import IamPolicyAnalysisOutputConfig
 from google.cloud.asset_v1.types.asset_service import IamPolicyAnalysisQuery
+from google.cloud.asset_v1.types.asset_service import ListAssetsRequest
+from google.cloud.asset_v1.types.asset_service import ListAssetsResponse
 from google.cloud.asset_v1.types.asset_service import ListFeedsRequest
 from google.cloud.asset_v1.types.asset_service import ListFeedsResponse
 from google.cloud.asset_v1.types.asset_service import OutputConfig
@@ -51,7 +52,9 @@ from google.cloud.asset_v1.types.asset_service import SearchAllIamPoliciesRespon
 from google.cloud.asset_v1.types.asset_service import SearchAllResourcesRequest
 from google.cloud.asset_v1.types.asset_service import SearchAllResourcesResponse
 from google.cloud.asset_v1.types.asset_service import UpdateFeedRequest
+from google.cloud.asset_v1.types.asset_service import ContentType
 from google.cloud.asset_v1.types.assets import Asset
+from google.cloud.asset_v1.types.assets import ConditionEvaluation
 from google.cloud.asset_v1.types.assets import IamPolicyAnalysisResult
 from google.cloud.asset_v1.types.assets import IamPolicyAnalysisState
 from google.cloud.asset_v1.types.assets import IamPolicySearchResult
@@ -61,17 +64,15 @@ from google.cloud.asset_v1.types.assets import TemporalAsset
 from google.cloud.asset_v1.types.assets import TimeWindow
 
 __all__ = (
+    "AssetServiceClient",
+    "AssetServiceAsyncClient",
     "AnalyzeIamPolicyLongrunningRequest",
     "AnalyzeIamPolicyLongrunningResponse",
     "AnalyzeIamPolicyRequest",
     "AnalyzeIamPolicyResponse",
-    "Asset",
-    "AssetServiceAsyncClient",
-    "AssetServiceClient",
     "BatchGetAssetsHistoryRequest",
     "BatchGetAssetsHistoryResponse",
     "BigQueryDestination",
-    "ContentType",
     "CreateFeedRequest",
     "DeleteFeedRequest",
     "ExportAssetsRequest",
@@ -83,22 +84,27 @@ __all__ = (
     "GetFeedRequest",
     "IamPolicyAnalysisOutputConfig",
     "IamPolicyAnalysisQuery",
-    "IamPolicyAnalysisResult",
-    "IamPolicyAnalysisState",
-    "IamPolicySearchResult",
+    "ListAssetsRequest",
+    "ListAssetsResponse",
     "ListFeedsRequest",
     "ListFeedsResponse",
     "OutputConfig",
     "OutputResult",
     "PartitionSpec",
     "PubsubDestination",
-    "Resource",
-    "ResourceSearchResult",
     "SearchAllIamPoliciesRequest",
     "SearchAllIamPoliciesResponse",
     "SearchAllResourcesRequest",
     "SearchAllResourcesResponse",
+    "UpdateFeedRequest",
+    "ContentType",
+    "Asset",
+    "ConditionEvaluation",
+    "IamPolicyAnalysisResult",
+    "IamPolicyAnalysisState",
+    "IamPolicySearchResult",
+    "Resource",
+    "ResourceSearchResult",
     "TemporalAsset",
     "TimeWindow",
-    "UpdateFeedRequest",
 )
