@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,6 +15,8 @@
 #
 
 from .services.asset_service import AssetServiceClient
+from .services.asset_service import AssetServiceAsyncClient
+
 from .types.asset_service import AnalyzeIamPolicyLongrunningRequest
 from .types.asset_service import AnalyzeIamPolicyLongrunningResponse
 from .types.asset_service import AnalyzeIamPolicyRequest
@@ -23,7 +24,6 @@ from .types.asset_service import AnalyzeIamPolicyResponse
 from .types.asset_service import BatchGetAssetsHistoryRequest
 from .types.asset_service import BatchGetAssetsHistoryResponse
 from .types.asset_service import BigQueryDestination
-from .types.asset_service import ContentType
 from .types.asset_service import CreateFeedRequest
 from .types.asset_service import DeleteFeedRequest
 from .types.asset_service import ExportAssetsRequest
@@ -35,6 +35,8 @@ from .types.asset_service import GcsOutputResult
 from .types.asset_service import GetFeedRequest
 from .types.asset_service import IamPolicyAnalysisOutputConfig
 from .types.asset_service import IamPolicyAnalysisQuery
+from .types.asset_service import ListAssetsRequest
+from .types.asset_service import ListAssetsResponse
 from .types.asset_service import ListFeedsRequest
 from .types.asset_service import ListFeedsResponse
 from .types.asset_service import OutputConfig
@@ -46,7 +48,9 @@ from .types.asset_service import SearchAllIamPoliciesResponse
 from .types.asset_service import SearchAllResourcesRequest
 from .types.asset_service import SearchAllResourcesResponse
 from .types.asset_service import UpdateFeedRequest
+from .types.asset_service import ContentType
 from .types.assets import Asset
+from .types.assets import ConditionEvaluation
 from .types.assets import IamPolicyAnalysisResult
 from .types.assets import IamPolicyAnalysisState
 from .types.assets import IamPolicySearchResult
@@ -55,16 +59,18 @@ from .types.assets import ResourceSearchResult
 from .types.assets import TemporalAsset
 from .types.assets import TimeWindow
 
-
 __all__ = (
+    "AssetServiceAsyncClient",
     "AnalyzeIamPolicyLongrunningRequest",
     "AnalyzeIamPolicyLongrunningResponse",
     "AnalyzeIamPolicyRequest",
     "AnalyzeIamPolicyResponse",
     "Asset",
+    "AssetServiceClient",
     "BatchGetAssetsHistoryRequest",
     "BatchGetAssetsHistoryResponse",
     "BigQueryDestination",
+    "ConditionEvaluation",
     "ContentType",
     "CreateFeedRequest",
     "DeleteFeedRequest",
@@ -80,6 +86,8 @@ __all__ = (
     "IamPolicyAnalysisResult",
     "IamPolicyAnalysisState",
     "IamPolicySearchResult",
+    "ListAssetsRequest",
+    "ListAssetsResponse",
     "ListFeedsRequest",
     "ListFeedsResponse",
     "OutputConfig",
@@ -95,5 +103,4 @@ __all__ = (
     "TemporalAsset",
     "TimeWindow",
     "UpdateFeedRequest",
-    "AssetServiceClient",
 )
