@@ -879,6 +879,10 @@ class SearchAllIamPoliciesRequest(proto.Message):
             -  ``resource:(instance1 OR instance2) policy:amy`` to find
                IAM policy bindings that are set on resources "instance1"
                or "instance2" and also specify user "amy".
+            -  ``roles:roles/compute.admin`` to find IAM policy bindings
+               that specify the Compute Admin role.
+            -  ``memberTypes:user`` to find IAM policy bindings that
+               contain the "user" member type.
         page_size (int):
             Optional. The page size for search result pagination. Page
             size is capped at 500 even if a larger value is given. If
@@ -892,12 +896,47 @@ class SearchAllIamPoliciesRequest(proto.Message):
             be the value of ``next_page_token`` from the previous
             response. The values of all other method parameters must be
             identical to those in the previous call.
+        asset_types (Sequence[str]):
+            Optional. A list of asset types that the IAM policies are
+            attached to. If empty, it will search the IAM policies that
+            are attached to all the `searchable asset
+            types <https://cloud.google.com/asset-inventory/docs/supported-asset-types#searchable_asset_types>`__.
+
+            Regular expressions are also supported. For example:
+
+            -  "compute.googleapis.com.*" snapshots IAM policies
+               attached to asset type starts with
+               "compute.googleapis.com".
+            -  ".*Instance" snapshots IAM policies attached to asset
+               type ends with "Instance".
+            -  ".*Instance.*" snapshots IAM policies attached to asset
+               type contains "Instance".
+
+            See `RE2 <https://github.com/google/re2/wiki/Syntax>`__ for
+            all supported regular expression syntax. If the regular
+            expression does not match any supported asset type, an
+            INVALID_ARGUMENT error will be returned.
+        order_by (str):
+            Optional. A comma-separated list of fields specifying the
+            sorting order of the results. The default order is
+            ascending. Add " DESC" after the field name to indicate
+            descending order. Redundant space characters are ignored.
+            Example: "assetType DESC, resource". Only singular primitive
+            fields in the response are sortable:
+
+            -  resource
+            -  assetType
+            -  project All the other fields such as repeated fields
+               (e.g., ``folders``) and non-primitive fields (e.g.,
+               ``policy``) are not supported.
     """
 
     scope = proto.Field(proto.STRING, number=1,)
     query = proto.Field(proto.STRING, number=2,)
     page_size = proto.Field(proto.INT32, number=3,)
     page_token = proto.Field(proto.STRING, number=4,)
+    asset_types = proto.RepeatedField(proto.STRING, number=5,)
+    order_by = proto.Field(proto.STRING, number=7,)
 
 
 class SearchAllIamPoliciesResponse(proto.Message):
