@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,17 +21,16 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.asset_v1p2beta1.types import asset_service
-
 from .transports.base import AssetServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AssetServiceGrpcTransport
 from .transports.grpc_asyncio import AssetServiceGrpcAsyncIOTransport
@@ -51,11 +48,8 @@ class AssetServiceClientMeta(type):
     _transport_registry["grpc"] = AssetServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = AssetServiceGrpcAsyncIOTransport
 
-    def get_transport_class(
-        cls,
-        label: str = None,
-    ) -> Type[AssetServiceTransport]:
-        """Return an appropriate transport class.
+    def get_transport_class(cls, label: str = None,) -> Type[AssetServiceTransport]:
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -78,7 +72,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -110,10 +105,27 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            AssetServiceClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -122,7 +134,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            AssetServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -132,35 +144,28 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
 
     @property
     def transport(self) -> AssetServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            AssetServiceTransport: The transport used by the client instance.
+            AssetServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
-    def feed_path(
-        project: str,
-        feed: str,
-    ) -> str:
-        """Return a fully-qualified feed string."""
-        return "projects/{project}/feeds/{feed}".format(
-            project=project,
-            feed=feed,
-        )
+    def feed_path(project: str, feed: str,) -> str:
+        """Returns a fully-qualified feed string."""
+        return "projects/{project}/feeds/{feed}".format(project=project, feed=feed,)
 
     @staticmethod
     def parse_feed_path(path: str) -> Dict[str, str]:
-        """Parse a feed path into its component segments."""
+        """Parses a feed path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/feeds/(?P<feed>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(
-        billing_account: str,
-    ) -> str:
-        """Return a fully-qualified billing_account string."""
+    def common_billing_account_path(billing_account: str,) -> str:
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -172,13 +177,9 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(
-        folder: str,
-    ) -> str:
-        """Return a fully-qualified folder string."""
-        return "folders/{folder}".format(
-            folder=folder,
-        )
+    def common_folder_path(folder: str,) -> str:
+        """Returns a fully-qualified folder string."""
+        return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -187,13 +188,9 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(
-        organization: str,
-    ) -> str:
-        """Return a fully-qualified organization string."""
-        return "organizations/{organization}".format(
-            organization=organization,
-        )
+    def common_organization_path(organization: str,) -> str:
+        """Returns a fully-qualified organization string."""
+        return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -202,13 +199,9 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(
-        project: str,
-    ) -> str:
-        """Return a fully-qualified project string."""
-        return "projects/{project}".format(
-            project=project,
-        )
+    def common_project_path(project: str,) -> str:
+        """Returns a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -217,14 +210,10 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(
-        project: str,
-        location: str,
-    ) -> str:
-        """Return a fully-qualified location string."""
+    def common_location_path(project: str, location: str,) -> str:
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project,
-            location=location,
+            project=project, location=location,
         )
 
     @staticmethod
@@ -236,12 +225,12 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AssetServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the asset service client.
+        """Instantiates the asset service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -249,10 +238,10 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.AssetServiceTransport]): The
+            transport (Union[str, AssetServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -288,21 +277,18 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -314,12 +300,14 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -334,8 +322,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -345,7 +333,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -364,9 +352,9 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         updates.
 
         Args:
-            request (:class:`~.asset_service.CreateFeedRequest`):
+            request (google.cloud.asset_v1p2beta1.types.CreateFeedRequest):
                 The request object. Create asset feed request.
-            parent (:class:`str`):
+            parent (str):
                 Required. The name of the
                 project/folder/organization where this
                 feed should be created in. It can only
@@ -376,10 +364,10 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 (such as "projects/my-project-id")", or
                 a project number (such as
                 "projects/12345").
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -387,7 +375,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.asset_service.Feed:
+            google.cloud.asset_v1p2beta1.types.Feed:
                 An asset feed used to export asset
                 updates to a destinations. An asset feed
                 filter controls what updates are
@@ -413,10 +401,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, asset_service.CreateFeedRequest):
             request = asset_service.CreateFeedRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -431,12 +417,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Done; return the response.
         return response
@@ -453,17 +434,17 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         r"""Gets details about an asset feed.
 
         Args:
-            request (:class:`~.asset_service.GetFeedRequest`):
+            request (google.cloud.asset_v1p2beta1.types.GetFeedRequest):
                 The request object. Get asset feed request.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the Feed and it must be in the
                 format of: projects/project_number/feeds/feed_id
                 folders/folder_number/feeds/feed_id
                 organizations/organization_number/feeds/feed_id
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -471,7 +452,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.asset_service.Feed:
+            google.cloud.asset_v1p2beta1.types.Feed:
                 An asset feed used to export asset
                 updates to a destinations. An asset feed
                 filter controls what updates are
@@ -497,10 +478,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, asset_service.GetFeedRequest):
             request = asset_service.GetFeedRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -515,12 +494,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Done; return the response.
         return response
@@ -538,19 +512,19 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         project/folder/organization.
 
         Args:
-            request (:class:`~.asset_service.ListFeedsRequest`):
+            request (google.cloud.asset_v1p2beta1.types.ListFeedsRequest):
                 The request object. List asset feeds request.
-            parent (:class:`str`):
+            parent (str):
                 Required. The parent
                 project/folder/organization whose feeds
                 are to be listed. It can only be using
                 project/folder/organization number (such
                 as "folders/12345")", or a project ID
                 (such as "projects/my-project-id").
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -558,7 +532,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.asset_service.ListFeedsResponse:
+            google.cloud.asset_v1p2beta1.types.ListFeedsResponse:
 
         """
         # Create or coerce a protobuf request object.
@@ -577,10 +551,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, asset_service.ListFeedsRequest):
             request = asset_service.ListFeedsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -595,12 +567,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Done; return the response.
         return response
@@ -617,18 +584,18 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         r"""Updates an asset feed configuration.
 
         Args:
-            request (:class:`~.asset_service.UpdateFeedRequest`):
+            request (google.cloud.asset_v1p2beta1.types.UpdateFeedRequest):
                 The request object. Update asset feed request.
-            feed (:class:`~.asset_service.Feed`):
+            feed (google.cloud.asset_v1p2beta1.types.Feed):
                 Required. The new values of feed details. It must match
                 an existing feed and the field ``name`` must be in the
                 format of: projects/project_number/feeds/feed_id or
                 folders/folder_number/feeds/feed_id or
                 organizations/organization_number/feeds/feed_id.
+
                 This corresponds to the ``feed`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -636,7 +603,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.asset_service.Feed:
+            google.cloud.asset_v1p2beta1.types.Feed:
                 An asset feed used to export asset
                 updates to a destinations. An asset feed
                 filter controls what updates are
@@ -662,10 +629,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, asset_service.UpdateFeedRequest):
             request = asset_service.UpdateFeedRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if feed is not None:
                 request.feed = feed
 
@@ -682,12 +647,7 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
-        )
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
 
         # Done; return the response.
         return response
@@ -704,17 +664,17 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         r"""Deletes an asset feed.
 
         Args:
-            request (:class:`~.asset_service.DeleteFeedRequest`):
+            request (google.cloud.asset_v1p2beta1.types.DeleteFeedRequest):
                 The request object.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the feed and it must be in the
                 format of: projects/project_number/feeds/feed_id
                 folders/folder_number/feeds/feed_id
                 organizations/organization_number/feeds/feed_id
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -737,10 +697,8 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, asset_service.DeleteFeedRequest):
             request = asset_service.DeleteFeedRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -756,18 +714,13 @@ class AssetServiceClient(metaclass=AssetServiceClientMeta):
 
         # Send the request.
         rpc(
-            request,
-            retry=retry,
-            timeout=timeout,
-            metadata=metadata,
+            request, retry=retry, timeout=timeout, metadata=metadata,
         )
 
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-asset",
-        ).version,
+        gapic_version=pkg_resources.get_distribution("google-cloud-asset",).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
