@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,20 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
+from .asset_service import (
+    ListAssetsRequest,
+    ListAssetsResponse,
+    ContentType,
+)
 from .assets import (
     Asset,
     Resource,
 )
-from .asset_service import (
-    ListAssetsRequest,
-    ListAssetsResponse,
-)
-
 
 __all__ = (
-    "Asset",
-    "Resource",
     "ListAssetsRequest",
     "ListAssetsResponse",
+    "ContentType",
+    "Asset",
+    "Resource",
 )
